@@ -1,12 +1,10 @@
-context("classbagg")
-
 test_that("classbagg + predict() works", {
   skip_on_cran()
   skip_if_not_installed("ipred")
   skip_if_not_installed("TH.data")
   # Load
-  library(ipred)
-  library(TH.data)
+  suppressPackageStartupMessages(library(ipred))
+  suppressPackageStartupMessages(library(TH.data))
   # Data
   data("GlaucomaM", package = "TH.data")
   # Fit
