@@ -1,10 +1,8 @@
-context("elnet")
-
 test_that("elnet + predict() works", {
   skip_on_cran()
   skip_if(do_not_run_glmnet)
   skip_if_not_installed("glmnet")
-  library(parsnip)
+  suppressPackageStartupMessages(library(parsnip))
   elnet_fit <- linear_reg(mixture = 0, penalty = 0.1) %>%
     set_engine("glmnet") %>%
     fit_xy(x = mtcars[, 2:11], y = mtcars[, 1, drop = FALSE])
